@@ -430,13 +430,25 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 				logger.info("Dataset created!");
 				toCreate.setId(datasetId);
 
-				// retrieve the url
-				//String datasetUrl =  utils.getUnencryptedUrlFromDatasetIdOrName(datasetId);
-				//toCreate.setSource(datasetUrl);
-				
 				//#23491 Building the go to the item to "Catalogue Portlet URL" (instead of URI Resolver URL)
 				String catalogueURL =  utils.getPortletUrl();
 				toCreate.setSource(String.format("%s?path=/dataset/%s", catalogueURL,datasetId));
+				logger.debug("Returning dataset: "+toCreate);
+				
+				//#24744 Returning lazy object
+				toCreate.setGroups(null);
+				toCreate.setCustomFields(null);
+				toCreate.setGroupsForceCreation(null);
+				toCreate.setMetadataList(null);
+				toCreate.setOrganizationList(null);
+				
+				logger.info("Returning lazy dataset: "+toCreate);
+				
+				//createdDatasetBean.getSource();
+				 //createdDatasetBean.getTitle();
+//				resourceForm = new AddResourceToDataset(eventBus, createdDatasetBean.getId(),
+//						createdDatasetBean.getTitle(),
+//						createdDatasetBean.getSelectedOrganization(), owner, datasetUrl);
 				return toCreate;
 			}else{
 				logger.error("Failed to create the dataset");
